ObsPipeWireSourceRef

Struct ObsPipeWireSourceRef 

pub struct ObsPipeWireSourceRef { /* private fields */ }
Available on Linux only.
General PipeWire source reference wrapper, which has a restore_token

Implementations

Source

impl ObsPipeWireSourceRef

pub fn inner_source(&self) -> &ObsSourceRef

pub fn inner_source_mut(&mut self) -> &mut ObsSourceRef

pub fn into_inner_source(self) -> ObsSourceRef

Consumes self and returns the inner ObsSourceRef

You can still update this source (if created by libobs-simple) and create an updater like so:

let updater = my_custom_source.create_updater()?;

let source = my_custom_source.into_inner_source();
let updater = source.create_updater::<MyCustomSourceUpdater>()?;
Source

impl ObsPipeWireSourceRef

pub fn new( source: ObsSourceRef, source_type: ObsPipeWireSourceType, ) -> Result<Self, ObsError>

Creates a new ObsPipeWireSourceRef from an ObsSourceRef.

pub fn get_restore_token(&self) -> Result<Option<String>, ObsError>

Gets the restore token used for reconnecting to previous sessions for pipewire-desktop-capture-source and pipewire-window-capture-source sources.

As of right now, there is no callback or signal to notify when the token has been set, you have to call this method to get the restore token.

The restore token will most probably be of Some(String) after the user has selected a screen or window to capture.

pub fn create_updater<'a>( &'a mut self, ) -> Result<ObsPipeWireGeneralUpdater<'a>, ObsError>

pub fn get_source_type(&self) -> ObsPipeWireSourceType