pub struct PipeWireCameraSourceBuilder { /* private fields */ }Available on Linux only.
A source for PipeWire camera capture via camera portal.
This source captures video from camera devices through PipeWire’s camera portal, providing secure access to camera devices in sandboxed environments.
Implementations
Sourceimpl PipeWireCameraSourceBuilder
impl PipeWireCameraSourceBuilder
Sourcepub fn set_camera_id<T: Into<ObsString> + Sync + Send>(
self,
camera_id: T,
) -> Self
pub fn set_camera_id<T: Into<ObsString> + Sync + Send>( self, camera_id: T, ) -> Self
Camera device node (e.g., “/dev/video0”)
Sourcepub fn set_video_format<T: Into<ObsString> + Sync + Send>(
self,
video_format: T,
) -> Self
pub fn set_video_format<T: Into<ObsString> + Sync + Send>( self, video_format: T, ) -> Self
Video format (FOURCC as string)
Sourcepub fn set_resolution<T: Into<ObsString> + Sync + Send>(
self,
resolution: T,
) -> Self
pub fn set_resolution<T: Into<ObsString> + Sync + Send>( self, resolution: T, ) -> Self
Resolution as “width x height”
Sourcepub fn set_framerate<T: Into<ObsString> + Sync + Send>(
self,
framerate: T,
) -> Self
pub fn set_framerate<T: Into<ObsString> + Sync + Send>( self, framerate: T, ) -> Self
Framerate as “num/den”
Sourceimpl PipeWireCameraSourceBuilder
impl PipeWireCameraSourceBuilder
Sourcepub fn set_resolution_values(self, width: u32, height: u32) -> Self
pub fn set_resolution_values(self, width: u32, height: u32) -> Self
Set resolution using width and height values
Sourcepub fn set_framerate_values(self, num: u32, den: u32) -> Self
pub fn set_framerate_values(self, num: u32, den: u32) -> Self
Set framerate using numerator and denominator